helga-amazon-meta
=================

.. image:: https://badge.fury.io/py/helga-amazon-meta.png
    :target: https://badge.fury.io/py/helga-amazon-meta

.. image:: https://travis-ci.org/narfman0/helga-amazon-metadata.png?branch=master
    :target: https://travis-ci.org/narfman0/helga-amazon-metadata

Provide information for amazon related metadata

Usage
-----

This plugin matches related chat and relates more information to users

License
-------

Copyright (c) 2016 Jon Robison

See included LICENSE for licensing information
